==> simple_karma-5.x-1.9.tar.gz: simple_karma/simple_karma.js <==
var KarmaSendForm = function() {
	var form = $(this);
	var args = {};
	var destination = form.find("input[@name=js_destination]").val();
        var karma_url=karma_base_path + 'simple_karma/handle';

	if (  destination ) {
		top.location = karma_base_path + karma_login_page + '?destination=' + destination;
		return false;
	}
	else {
		args.karma_vote 	= form.find("input[@name=karma_vote]").val()||form.find("select").val();
		//alert(form.find("input[@name=karma_vote]").val());
		//alert(form.find("select").val());
		args.oid 		= form.find("input[@name=oid]").val();
		args.otype 		= form.find("input[@name=otype]").val();
		args.form_type 		= 'ajax';
		form.addClass("karma_sending");
		$.ajax({
			data		: args,
			url		: karma_url,
			type		: 'get',
			dataType: 'json',
			success	: function(json){
				var ts;
				for(var x in json) {args[x] = json[x];}
				if (json.error) {
					form.find(".tmpClicked").removeClass("tmpClicked");
					alert(json.error);
				} else {
					KarmaStripForm(form,args);
					form.addClass("karma_success");
					form.find("label").removeClass("karma_clicked");
					form.find(".tmpClicked").addClass("karma_clicked").removeClass("tmpClicked");
					(karma_hide_comment)(form.find(".karma_down"));
				}
			},
			error : function(xhr,msg){
				form.find(".tmpClicked").removeClass("tmpClicked");
				if (xhr.status==404||!msg) {
					alert("Karma Error: Communication (0)");
				} else {
					alert("Karma Error: "+msg);
				}
			},
			complete: function(xhr,stat) {
				(function(form,args){
					window.setTimeout(function(){
						form.removeClass("karma_sending");
					},2000);
				})(form,args);
			}
		});
		return false;
	}
}

var KarmaStripForm  = function(form,args) {
	switch(form.find("input[@name=form_style]").val()) {
		case "1":
		case "2":
			if (karma_only_one_vote) {
				form.find("select").attr("disabled","disabled");
			}
			break;
		case "3":
		case "4":
			if (karma_only_one_vote) {
				form.find("label").removeClass("karma_clickable").addClass("karma_not_clickable").click(function(){return false;});
			}
			break;
	}
	var fid = form.attr("id");
	if ( args.karma_aggregate != "Undefined") {
		for ( var prefix in ( { 'w': 1, 'x': 1, 'y': 1, 'z': 1} ) ) {
			var did = prefix + args.oid;
			$("#" + did + " span.karma_score").text(args.karma_aggregate);
			var did = prefix + args.oid;
			if ( did != fid ) {
				$("#" + did + " *").attr("disabled", "true");
				$("#" + did + " label").removeClass("karma_clickable").addClass("karma_not_clickable").unbind('click');
			}
		}
	}
 
};

var KarmaRenderForm = function() {
	var form   = $(this);
	var submit = form.find("input[@type=submit]");

  form.css('visibility', 'Visible');
	submit.hide();

	switch(form.find("input[@name=form_style]").val()) {
		case '1':
		case '2':
			if (submit.attr("disabled")) {
				form.find("select").attr("disabled","true");
				form.find("label").addClass("karma_not_clickable");
			} else {
				form.find("select").change(function(){form.submit();});
			}
			break;
		case '3':
		case '4':
			form.find("input[@name=karma_vote]").each(function(){
				$(this).after('<input type="hidden" name="'+this.id+'" value="'+$(this).val()+'"/>');
				$(this).remove();
			});
			form.append('<input name="karma_vote" type="hidden" value="0"/>');
   			form.find("label.karma_up").html("");
   			form.find("label.karma_down").html("");
			if (submit.attr("disabled")) {
				form.find("label").addClass("karma_not_clickable");
			} else {
				form.find("label").addClass("karma_clickable").click(function(){
					$(this).addClass("tmpClicked");
					form.find("input[@name=karma_vote]").val(form.find("input[@name="+$(this).attr("for")+"]").val());
					form.submit();
				});
			}
			break;
	}
}
var karma_comment_show = function() {
	var button = $(this);
	var parent = button.parent();

	if ( $(".karma_comment_show" ).find(this).length > 0 ) {
		button.removeClass("karma_comment_show");
		button.addClass("karma_comment_hide");
		parent.find("div").each( karma_restore_display );
	}
	else if ( $(".karma_comment_hide" ).find(this).length > 0 ) {
		button.removeClass("karma_comment_hide");
		button.addClass("karma_comment_show");
		parent.find("div").css('display', 'none');
	}
}

var karma_save_display = function() {
	var item = $(this);
	item.attr( "karma-save-display", item.css( 'display' ));
}

var karma_restore_display = function() {
	var item = $(this);
	var disp = item.attr( "karma-save-display" );
	if ( disp ) {
		item.css( "display", disp );
	}
}

var karma_hide_comment = function( val ) {
	var clicked = $(this);
	if ( val && typeof val != 'number' )
	{
		clicked = $(val);
	}
	var comment = clicked.parents( ".comment" );
	if ( comment.find(".karma_down.karma_clicked").length > 0 )
	{
		if ( !( comment.find(".karma_comment_show").length > 0) && !( comment.find(".karma_comment_hide" ).length > 0 )) {
			comment.find('div').each(karma_save_display);
			comment.find('.title').after("<span class='karma_comment_show'>&nbsp;&nbsp;</span>")
			comment.find('.karma_comment_show').click(karma_comment_show);
		}
		comment.find('div').css('display','none');
	}
}

$(function(){
	$("form.karma_form").submit(KarmaSendForm).each(KarmaRenderForm);
	$(".karma_clicked.karma_down").each(karma_hide_comment);
});

==> simple_karma-5.x-1.10.tar.gz: simple_karma/simple_karma.js <==
var KarmaSendForm = function() {
	var form = $(this);
	var args = {};
	var destination = form.find("input[@name=js_destination]").val();
        var karma_url=karma_base_path + 'simple_karma/handle';

	if (  destination ) {
		top.location = karma_base_path + karma_login_page + '?destination=' + destination;
		return false;
	}
	else {
		args.karma_vote 	= form.find("input[@name=karma_vote]").val()||form.find("select").val();
		//alert(form.find("input[@name=karma_vote]").val());
		//alert(form.find("select").val());
		args.oid 		= form.find("input[@name=oid]").val();
		args.otype 		= form.find("input[@name=otype]").val();
		args.form_type 		= 'ajax';
		form.addClass("karma_sending");
		if ( form.find('.karma_clicked.tmpClicked').length > 0 ) {
			form.find('.tmpClicked').removeClass('tmpClicked');
			return false;
		}
		$.ajax({
			data		: args,
			url		: karma_url,
			type		: 'get',
			dataType: 'json',
			success	: function(json){
				var ts;
				for(var x in json) {args[x] = json[x];}
				if (json.error) {
					form.find(".tmpClicked").removeClass("tmpClicked");
					alert(json.error);
				} else {
					KarmaStripForm(form,args);
					form.addClass("karma_success");
					form.find("label").removeClass("karma_clicked");
					form.find(".tmpClicked").addClass("karma_clicked").removeClass("tmpClicked");
					(karma_hide_comment)(form.find(".karma_down"));
				}
			},
			error : function(xhr,msg){
				form.find(".tmpClicked").removeClass("tmpClicked");
				if (xhr.status==404||!msg) {
					alert("Karma Error: Communication (0)");
				} else {
					alert("Karma Error: "+msg);
				}
			},
			complete: function(xhr,stat) {
				(function(form,args){
					window.setTimeout(function(){
						form.removeClass("karma_sending");
					},2000);
				})(form,args);
			}
		});
		return false;
	}
}

var KarmaStripForm  = function(form,args) {
	switch(form.find("input[@name=form_style]").val()) {
		case "1":
		case "2":
			if (karma_only_one_vote) {
				form.find("select").attr("disabled","disabled");
			}
			break;
		case "3":
		case "4":
			if (karma_only_one_vote) {
				form.find("label").removeClass("karma_clickable").addClass("karma_not_clickable").click(function(){return false;});
			}
			break;
	}
	var fid = form.attr("id");
	if ( args.karma_aggregate != "Undefined") {
		for ( var prefix in ( { 'w': 1, 'x': 1, 'y': 1, 'z': 1} ) ) {
			var did = prefix + args.oid;
			$("#" + did + " span.karma_score").text(args.karma_aggregate);
			var did = prefix + args.oid;
			if ( did != fid ) {
				$("#" + did + " *").attr("disabled", "true");
				$("#" + did + " label").removeClass("karma_clickable").addClass("karma_not_clickable").unbind('click');
			}
		}
	}
};

var KarmaRenderForm = function() {
	var form   = $(this);
	var submit = form.find("input[@type=submit]");

  form.css('visibility', 'Visible');
	submit.hide();

	switch(form.find("input[@name=form_style]").val()) {
		case '1':
		case '2':
			if (submit.attr("disabled")) {
				form.find("select").attr("disabled","true");
				form.find("label").addClass("karma_not_clickable");
			} else {
				form.find("select").change(function(){form.submit();});
			}
			break;
		case '3':
		case '4':
			form.find("input[@name=karma_vote]").each(function(){
				$(this).after('<input type="hidden" name="'+this.id+'" value="'+$(this).val()+'"/>');
				$(this).remove();
			});
			form.append('<input name="karma_vote" type="hidden" value="0"/>');
   			form.find("label.karma_up > span").html("");
   			form.find("label.karma_down > span").html("");
			if (submit.attr("disabled")) {
				form.find("label").addClass("karma_not_clickable");
			} else {
				form.find("label").addClass("karma_clickable").click(function(){
					$(this).addClass("tmpClicked");
					form.find("input[@name=karma_vote]").val(form.find("input[@name="+$(this).attr("for")+"]").val());
					form.submit();
				});
			}
			break;
	}
}


/*
var karma_comment_show = function() {
	var button = $(this);
	var parent = button.parent();

	if ( $(".karma_comment_show" ).find(this).length > 0 ) {
		button.removeClass("karma_comment_show");
		button.addClass("karma_comment_hide");
		parent.find("div").each( karma_restore_display );
	}
	else if ( $(".karma_comment_hide" ).find(this).length > 0 ) {
		button.removeClass("karma_comment_hide");
		button.addClass("karma_comment_show");
		parent.find("div").css('display', 'none');
	}
}

var karma_save_display = function() {
	var item = $(this);
	item.attr( "karma-save-display", item.css( 'display' ));
}

var karma_restore_display = function() {
	var item = $(this);
	var disp = item.attr( "karma-save-display" );
	if ( disp ) {
		item.css( "display", disp );
	}
}

var karma_hide_comment = function( val ) {
	var clicked = $(this);
	if ( val && typeof val != 'number' )
	{
		clicked = $(val);
	}
	var comment = clicked.parents( ".comment" );
	if ( comment.find(".karma_down.karma_clicked").length > 0 )
	{
		if ( !( comment.find(".karma_comment_show").length > 0) && !( comment.find(".karma_comment_hide" ).length > 0 )) {
			comment.find('div').each(karma_save_display);
			comment.find('.title').after("<span class='karma_comment_show'>&nbsp;&nbsp;</span>")
			comment.find('.karma_comment_show').click(karma_comment_show);
		}
		comment.find('div').css('display','none');
	}
}
*/

$(function(){
	$("form.karma_form").submit(KarmaSendForm).each(KarmaRenderForm);
	$(".karma_clicked.karma_down").each(karma_hide_comment);
});
